Blind WaterMark for pypicgo
===========================

Blind WaterMark for `PyPicGo <https://github.com/AnsGoo/PyPicGo>`__
append blind watermark to images

install
-------

.. code:: shell

   pip install pypicgo-blind-watermark-plugin

config
------

.. code:: yaml

   tinypng:
     module: pypicgo_blind_watermark_plugin.BlindWaterMarkPlugin
     config:
       mark: xxxxxxxxxxxxxxx
